	# -*- coding: utf-8 -*-
#
# Copyright (C) 2019 alvations
# URL:
# For license information, see LICENSE.md

from distutils.core import setup

setup(
    name='gudetama',
    version='0.0.1',
    packages=['gudetama',],
    url = 'https://github.com/alvations/gudetama',
    description='Lazy python recipes with batteries',
    license="MIT",
)
